from setuptools import find_packages, setup
from lbadminlte import __version__

setup(
    name='django-lb-adminlte',
    version=__version__,
    url='https://github.com/vicalloy/django-lb-adminlte',
    author='vicalloy',
    author_email='vicalloy@gmail.com',
    description="Reusable AdminLTE templates library for Django",
    license='BSD',
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    install_requires=[
        'Django>=1.8',
        'django-crispy-forms>=1.6',
        'django-lbutils>=1.0.2',
        'django-compressor>=2.1.1',
        'django-bower>=5.2.0',
    ],
    extras_require={
        'tests': [
            'coverage',
            'flake8>=2.0,<3.0',
            'isort',
        ]
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



from django.core.urlresolvers import reverse
from django.test import TestCase


class LBAdminLTETests(TestCase):
    def test_base_template(self):
        resp = self.client.get(reverse('base'))
        self.assertEqual(resp.status_code, 200)

    def test_base_ext_template(self):
        resp = self.client.get(reverse('base_ext'))
        self.assertEqual(resp.status_code, 200)

    def test_form_template(self):
        resp = self.client.get(reverse('form'))
        self.assertEqual(resp.status_code, 200)
